@@ -2,7 +2,6 @@
 from abc import abstractmethod
 
 import pandas as pd
-from pandas.core.indexes import range
 
 from evalml.exceptions import MethodPropertyNotFoundError
 from evalml.model_family import ModelFamily
@@ -92,8 +91,6 @@ class Estimator(ComponentBase):
         """
         try:
             X = infer_feature_types(X)
-            if isinstance(X.columns, range.RangeIndex):
-                X.columns = [x for x in X.columns]
             predictions = self._component_obj.predict(X)
         except AttributeError:
             raise MethodPropertyNotFoundError(
