@@ -3,10 +3,7 @@ import pandas as pd
 
 from evalml.exceptions import MethodPropertyNotFoundError
 from evalml.pipelines.components.transformers import Transformer
-from evalml.utils import (
-    _retain_custom_types_and_initalize_woodwork,
-    infer_feature_types,
-)
+from evalml.utils import infer_feature_types
 
 
 class FeatureSelector(Transformer):
@@ -56,15 +53,10 @@ class FeatureSelector(Transformer):
                 "Feature selector requires a transform method or a component_obj that implements transform"
             )
 
-        X_dtypes = X_ww.dtypes.to_dict()
         selected_col_names = self.get_names()
-        col_types = {key: X_dtypes[key] for key in selected_col_names}
-        features = pd.DataFrame(
-            X_t, columns=selected_col_names, index=X_ww.index
-        ).astype(col_types)
-        return _retain_custom_types_and_initalize_woodwork(
-            X_ww.ww.logical_types, features
-        )
+        features = pd.DataFrame(X_t, columns=selected_col_names, index=X_ww.index)
+        features.ww.init(schema=X_ww.ww.schema.get_subset_schema(selected_col_names))
+        return features
 
     def fit_transform(self, X, y=None):
         """Fit and transform data using the feature selector.
