@@ -24,6 +24,7 @@ from evalml.pipelines.components import (  # noqa: F401
     CatBoostRegressor,
     ComponentBase,
     DateTimeFeaturizer,
+    DFSTransformer,
     DropColumns,
     DropNaNRowsTransformer,
     DropNullColumns,
@@ -227,8 +228,8 @@ def _get_drop_nan_rows_transformer(
     X, y, problem_type, estimator_class, sampler_name=None
 ):
     components = []
-    if is_time_series(problem_type) and estimator_unable_to_handle_nans(
-        estimator_class
+    if is_time_series(problem_type) and (
+        estimator_unable_to_handle_nans(estimator_class) or sampler_name
     ):
         components.append(DropNaNRowsTransformer)
     return components
@@ -261,9 +262,9 @@ def _get_preprocessing_components(
             _get_time_series_featurizer,
             _get_datetime,
             _get_ohe,
+            _get_drop_nan_rows_transformer,
             _get_sampler,
             _get_standard_scaler,
-            _get_drop_nan_rows_transformer,
         ]
     else:
         components_functions = [
@@ -346,7 +347,10 @@ def _make_pipeline_time_series(
 
     if known_in_advance:
         preprocessing_components = [SelectColumns] + preprocessing_components
-        if DropNaNRowsTransformer in preprocessing_components:
+        if (
+            Oversampler not in preprocessing_components
+            and DropNaNRowsTransformer in preprocessing_components
+        ):
             preprocessing_components.remove(DropNaNRowsTransformer)
     else:
         preprocessing_components += [estimator]
@@ -409,6 +413,7 @@ def make_pipeline(
     extra_components_after=None,
     use_estimator=True,
     known_in_advance=None,
+    features=False,
 ):
     """Given input data, target data, an estimator class and the problem type, generates a pipeline class with a preprocessing chain which was recommended based on the inputs. The pipeline will be a subclass of the appropriate pipeline base class for the specified problem_type.
 
@@ -425,6 +430,8 @@ def make_pipeline(
          extra_components_after (list[ComponentBase]): List of extra components to be added after preprocessing components. Defaults to None.
          use_estimator (bool): Whether to add the provided estimator to the pipeline or not. Defaults to True.
          known_in_advance (list[str], None): List of features that are known in advance.
+         features (bool): Whether to add a DFSTransformer component to this pipeline.
+
 
     Returns:
          PipelineBase object: PipelineBase instance with dynamically generated preprocessing components and specified estimator.
@@ -456,9 +463,11 @@ def make_pipeline(
         )
         extra_components_before = extra_components_before or []
         extra_components_after = extra_components_after or []
+        dfs_transformer = [DFSTransformer] if features else []
         estimator_component = [estimator] if use_estimator else []
         complete_component_list = (
-            extra_components_before
+            dfs_transformer
+            + extra_components_before
             + preprocessing_components
             + extra_components_after
             + estimator_component
@@ -649,6 +658,7 @@ def _make_pipeline_from_multiple_graphs(
     parameters=None,
     pipeline_name=None,
     sub_pipeline_names=None,
+    prior_components=None,
     random_seed=0,
 ):
     """Creates a pipeline from multiple preprocessing pipelines and a final estimator. Final y input to the estimator will be chosen from the last of the input pipelines.
@@ -660,6 +670,7 @@ def _make_pipeline_from_multiple_graphs(
         parameters (Dict): Parameters to initialize pipeline with. Defaults to an empty dictionary.
         pipeline_name (str): Custom name for the final pipeline.
         sub_pipeline_names (Dict): Dictionary mapping original input pipeline names to new names. This will be used to rename components. Defaults to None.
+        prior_components (Dict): Component graph of components preceding the split of multiple graphs. Must be in component graph format, {"Label Encoder": ["Label Encoder", "X", "y"]} and currently restricted to components that only alter X input.
         random_seed (int): Random seed for the pipeline. Defaults to 0.
 
     Returns:
@@ -677,11 +688,15 @@ def _make_pipeline_from_multiple_graphs(
     parameters = copy.deepcopy(parameters) if parameters else {}
     final_components = []
     used_names = []
-    component_graph = (
-        {"Label Encoder": ["Label Encoder", "X", "y"]}
-        if is_classification(problem_type)
-        else {}
+
+    prior_components = {} if not prior_components else prior_components
+    last_prior_component = (
+        list(prior_components.keys())[-1] if prior_components else None
     )
+    component_graph = prior_components
+    if is_classification(problem_type):
+        component_graph.update({"Label Encoder": ["Label Encoder", "X", "y"]})
+
     for pipeline in input_pipelines:
         component_pipeline_name = pipeline.name
         name_idx = (
@@ -714,6 +729,11 @@ def _make_pipeline_from_multiple_graphs(
             new_component_name = _make_new_component_name(
                 component_pipeline_name, name, name_idx, sub_pipeline_name
             )
+            first_x_component = (
+                pipeline.component_graph.compute_order[0]
+                if pipeline.component_graph.compute_order[0] != "Label Encoder"
+                else pipeline.component_graph.compute_order[1]
+            )
             for i, item in enumerate(component_list):
                 if i == 0:
                     fitted_comp = handle_component_class(item)
@@ -734,6 +754,9 @@ def _make_pipeline_from_multiple_graphs(
                         new_component_list.append("Label Encoder.y")
                     else:
                         new_component_list.append("y")
+                elif name == first_x_component and last_prior_component:
+                    # if we have prior components, change the X input from the first component of each sub-pipeline to be the last prior components X output.
+                    new_component_list.append(f"{last_prior_component}.x")
                 else:
                     new_component_list.append(item)
             component_graph[new_component_name] = new_component_list
