@@ -149,7 +149,7 @@ def test_train_pipeline_trains_and_tunes_threshold_ts(
     automl_config = AutoMLConfig(
         None, "time series binary", LogLossBinary(), [], F1(), True, None, 0, None, None
     )
-    cv_pipeline = train_pipeline(ts_binary, X, y, automl_config=automl_config)
+    cv_pipeline, _ = train_pipeline(ts_binary, X, y, automl_config=automl_config)
     assert cv_pipeline.threshold is not None
 
 
@@ -162,3 +162,63 @@ def test_job_logger_warning_and_error_messages(caplog):
 
     assert "This is a warning!" in caplog.text
     assert "This is an error!" in caplog.text
+
+
+def test_train_pipelines_cache(
+    AutoMLTestEnv,
+    dummy_classifier_estimator_class,
+    dummy_binary_pipeline,
+    X_y_binary,
+    caplog,
+):
+    X, y = X_y_binary
+    X = pd.DataFrame(X)
+    automl_config = AutoMLConfig(
+        None, "binary", LogLossBinary(), [], None, True, None, 0, None, None
+    )
+    env = AutoMLTestEnv("binary")
+    with env.test_context():
+        res = train_pipeline(
+            dummy_binary_pipeline, X, y, automl_config=automl_config, get_hashes=False
+        )
+    assert isinstance(res, tuple)
+    assert res[1] is None
+
+    with env.test_context():
+        res = train_pipeline(
+            dummy_binary_pipeline, X, y, automl_config=automl_config, get_hashes=True
+        )
+    assert isinstance(res, tuple)
+    assert res[1] == hash(tuple(X.index))
+
+
+def test_train_and_score_pipelines_cache(
+    AutoMLTestEnv,
+    dummy_classifier_estimator_class,
+    dummy_binary_pipeline,
+    X_y_binary,
+):
+    X, y = X_y_binary
+    X = pd.DataFrame(X)
+    automl = AutoMLSearch(
+        X_train=X,
+        y_train=y,
+        problem_type="binary",
+        max_time=1,
+        max_batches=1,
+        allowed_component_graphs={
+            "Mock Binary Classification Pipeline": [dummy_classifier_estimator_class]
+        },
+        optimize_thresholds=False,
+    )
+    env = AutoMLTestEnv("binary")
+    with env.test_context(score_return_value={automl.objective.name: 0.42}):
+        evaluation_result = evaluate_pipeline(
+            dummy_binary_pipeline,
+            automl.automl_config,
+            automl.X_train,
+            automl.y_train,
+            logger=MagicMock(),
+        ).get("cached_data")
+    assert evaluation_result
+    assert len(evaluation_result) == automl.data_splitter.n_splits
