@@ -26,9 +26,9 @@ def test_baseline_y_is_None(X_y_binary):
         BaselineClassifier().fit(X, y=None)
 
 
-@pytest.mark.parametrize('data_type', ['pd', 'ww'])
+@pytest.mark.parametrize("data_type", ["pd", "ww"])
 def test_baseline_binary_mode(data_type, make_data_type):
-    X = pd.DataFrame({'one': [1, 2, 3, 4], 'two': [2, 3, 4, 5], 'three': [1, 2, 3, 4]})
+    X = pd.DataFrame({"one": [1, 2, 3, 4], "two": [2, 3, 4, 5], "three": [1, 2, 3, 4]})
     y = pd.Series([10, 11, 10, 10])
     X = make_data_type(data_type, X)
     y = make_data_type(data_type, y)
@@ -43,7 +43,9 @@ def test_baseline_binary_mode(data_type, make_data_type):
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (X.shape[0], 2)
-    expected_predictions_proba = pd.DataFrame({10: [1., 1., 1., 1.], 11: [0., 0., 0., 0.]})
+    expected_predictions_proba = pd.DataFrame(
+        {10: [1.0, 1.0, 1.0, 1.0], 11: [0.0, 0.0, 0.0, 0.0]}
+    )
     assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
@@ -56,13 +58,17 @@ def test_baseline_binary_random(X_y_binary):
     clf.fit(X, y)
     assert clf.classes_ == [0, 1]
 
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X)), dtype="int64")
+    expected_predictions = pd.Series(
+        get_random_state(0).choice(np.unique(y), len(X)), dtype="int64"
+    )
     predictions = clf.predict(X)
     assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 2)
-    expected_predictions_proba = pd.DataFrame(np.array([[0.5 for i in range(len(values))]] * len(X)))
+    expected_predictions_proba = pd.DataFrame(
+        np.array([[0.5 for i in range(len(values))]] * len(X))
+    )
     assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
@@ -78,20 +84,24 @@ def test_baseline_binary_random_weighted(X_y_binary):
     clf.fit(X, y)
 
     assert clf.classes_ == [0, 1]
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="int64")
+    expected_predictions = pd.Series(
+        get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="int64"
+    )
     predictions = clf.predict(X)
     assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 2)
-    expected_predictions_proba = pd.DataFrame(np.array([[percent_freq[i] for i in range(len(values))]] * len(X)))
+    expected_predictions_proba = pd.DataFrame(
+        np.array([[percent_freq[i] for i in range(len(values))]] * len(X))
+    )
     assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
 
 def test_baseline_multiclass_mode():
-    X = pd.DataFrame({'one': [1, 2, 3, 4], 'two': [2, 3, 4, 5], 'three': [1, 2, 3, 4]})
+    X = pd.DataFrame({"one": [1, 2, 3, 4], "two": [2, 3, 4, 5], "three": [1, 2, 3, 4]})
     y = pd.Series([10, 12, 11, 11])
     clf = BaselineClassifier(strategy="mode")
     clf.fit(X, y)
@@ -103,7 +113,9 @@ def test_baseline_multiclass_mode():
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
-    expected_predictions_proba = pd.DataFrame({10: [0., 0., 0., 0.], 11: [1., 1., 1., 1.], 12: [0., 0., 0., 0.]})
+    expected_predictions_proba = pd.DataFrame(
+        {10: [0.0, 0.0, 0.0, 0.0], 11: [1.0, 1.0, 1.0, 1.0], 12: [0.0, 0.0, 0.0, 0.0]}
+    )
     assert_frame_equal(expected_predictions_proba, predicted_proba)
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
@@ -116,13 +128,18 @@ def test_baseline_multiclass_random(X_y_multi):
     clf.fit(X, y)
 
     assert clf.classes_ == [0, 1, 2]
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X)), dtype="int64")
+    expected_predictions = pd.Series(
+        get_random_state(0).choice(np.unique(y), len(X)), dtype="int64"
+    )
     predictions = clf.predict(X)
     assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
-    assert_frame_equal(pd.DataFrame(np.array([[1. / 3 for i in range(len(values))]] * len(X))), predicted_proba)
+    assert_frame_equal(
+        pd.DataFrame(np.array([[1.0 / 3 for i in range(len(values))]] * len(X))),
+        predicted_proba,
+    )
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
 
@@ -135,13 +152,20 @@ def test_baseline_multiclass_random_weighted(X_y_multi):
     clf.fit(X, y)
 
     assert clf.classes_ == [0, 1, 2]
-    expected_predictions = pd.Series(get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="int64")
+    expected_predictions = pd.Series(
+        get_random_state(0).choice(np.unique(y), len(X), p=percent_freq), dtype="int64"
+    )
     predictions = clf.predict(X)
     assert_series_equal(expected_predictions, predictions)
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
-    assert_frame_equal(pd.DataFrame(np.array([[percent_freq[i] for i in range(len(values))]] * len(X))), predicted_proba)
+    assert_frame_equal(
+        pd.DataFrame(
+            np.array([[percent_freq[i] for i in range(len(values))]] * len(X))
+        ),
+        predicted_proba,
+    )
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
 
@@ -159,6 +183,9 @@ def test_baseline_no_mode():
 
     predicted_proba = clf.predict_proba(X)
     assert predicted_proba.shape == (len(X), 3)
-    assert_frame_equal(pd.DataFrame(np.array([[1.0 if i == 0 else 0.0 for i in range(3)]] * len(X))), predicted_proba)
+    assert_frame_equal(
+        pd.DataFrame(np.array([[1.0 if i == 0 else 0.0 for i in range(3)]] * len(X))),
+        predicted_proba,
+    )
 
     np.testing.assert_allclose(clf.feature_importance, np.array([0.0] * X.shape[1]))
