@@ -5,12 +5,13 @@ import woodwork as ww
 
 from evalml.automl import get_default_primary_search_objective
 from evalml.data_checks import (
-    DataCheckAction,
     DataCheckActionCode,
+    DataCheckActionOption,
     DataCheckError,
     DataCheckMessageCode,
     DataChecks,
     DataCheckWarning,
+    DCAOParameterType,
     InvalidTargetDataCheck,
 )
 from evalml.exceptions import DataCheckInitError
@@ -47,23 +48,15 @@ def test_invalid_target_data_check_nan_error():
         "regression", get_default_primary_search_objective("regression")
     )
 
-    assert invalid_targets_check.validate(X, y=pd.Series([1, 2, 3])) == {
-        "warnings": [],
-        "errors": [],
-        "actions": [],
-    }
-    assert invalid_targets_check.validate(X, y=pd.Series([np.nan, np.nan, np.nan])) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Target is either empty or fully null.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_IS_EMPTY_OR_FULLY_NULL,
-                details={},
-            ).to_dict(),
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y=pd.Series([1, 2, 3])) == []
+    assert invalid_targets_check.validate(X, y=pd.Series([np.nan, np.nan, np.nan])) == [
+        DataCheckError(
+            message="Target is either empty or fully null.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_IS_EMPTY_OR_FULLY_NULL,
+            details={},
+        ).to_dict(),
+    ]
 
 
 def test_invalid_target_data_check_numeric_binary_classification_valid_float():
@@ -72,11 +65,7 @@ def test_invalid_target_data_check_numeric_binary_classification_valid_float():
     invalid_targets_check = InvalidTargetDataCheck(
         "binary", get_default_primary_search_objective("binary")
     )
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == []
 
 
 def test_invalid_target_data_check_multiclass_two_examples_per_class():
@@ -88,34 +77,26 @@ def test_invalid_target_data_check_multiclass_two_examples_per_class():
     expected_message = "Target does not have at least two instances per class which is required for multiclass classification"
 
     # with 1 class not having min 2 instances
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message=expected_message,
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_MULTICLASS_NOT_TWO_EXAMPLES_PER_CLASS,
-                details={"least_populated_class_labels": [0]},
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == [
+        DataCheckError(
+            message=expected_message,
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_MULTICLASS_NOT_TWO_EXAMPLES_PER_CLASS,
+            details={"least_populated_class_labels": [0]},
+        ).to_dict()
+    ]
 
     y = pd.Series([0] + [1] + [2] * 98)
     X = pd.DataFrame({"col": range(len(y))})
     # with 2 classes not having min 2 instances
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message=expected_message,
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_MULTICLASS_NOT_TWO_EXAMPLES_PER_CLASS,
-                details={"least_populated_class_labels": [0, 1]},
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == [
+        DataCheckError(
+            message=expected_message,
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_MULTICLASS_NOT_TWO_EXAMPLES_PER_CLASS,
+            details={"least_populated_class_labels": [0, 1]},
+        ).to_dict()
+    ]
 
 
 @pytest.mark.parametrize(
@@ -130,55 +111,43 @@ def test_invalid_target_data_check_invalid_pandas_data_types_error(pd_type):
         "binary", get_default_primary_search_objective("binary")
     )
 
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == []
 
     y = pd.Series(pd.date_range("2000-02-03", periods=5, freq="W"))
     X = pd.DataFrame({"col": range(len(y))})
 
     unique_values = y.value_counts().index.tolist()
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Target is unsupported {} type. Valid Woodwork logical types include: {}".format(
-                    "Datetime",
-                    ", ".join([ltype for ltype in numeric_and_boolean_ww]),
-                ),
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_UNSUPPORTED_TYPE,
-                details={"unsupported_type": "datetime"},
-            ).to_dict(),
-            DataCheckError(
-                message="Binary class targets require exactly two unique values.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
-                details={"target_values": unique_values},
-            ).to_dict(),
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == [
+        DataCheckError(
+            message="Target is unsupported {} type. Valid Woodwork logical types include: {}".format(
+                "Datetime",
+                ", ".join([ltype for ltype in numeric_and_boolean_ww]),
+            ),
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_UNSUPPORTED_TYPE,
+            details={"unsupported_type": "datetime"},
+        ).to_dict(),
+        DataCheckError(
+            message="Binary class targets require exactly two unique values.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
+            details={"target_values": unique_values},
+        ).to_dict(),
+    ]
 
 
 def test_invalid_target_y_none():
     invalid_targets_check = InvalidTargetDataCheck(
         "binary", get_default_primary_search_objective("binary")
     )
-    assert invalid_targets_check.validate(pd.DataFrame(), y=None) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Target is None",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_IS_NONE,
-                details={},
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(pd.DataFrame(), y=None) == [
+        DataCheckError(
+            message="Target is None",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_IS_NONE,
+            details={},
+        ).to_dict()
+    ]
 
 
 def test_invalid_target_data_input_formats():
@@ -189,46 +158,44 @@ def test_invalid_target_data_input_formats():
     # test empty pd.Series
     X = pd.DataFrame()
     messages = invalid_targets_check.validate(X, pd.Series())
-    assert messages == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Target is either empty or fully null.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_IS_EMPTY_OR_FULLY_NULL,
-                details={},
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert messages == [
+        DataCheckError(
+            message="Target is either empty or fully null.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_IS_EMPTY_OR_FULLY_NULL,
+            details={},
+        ).to_dict()
+    ]
 
-    expected = {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="3 row(s) (75.0%) of target values are null",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_HAS_NULL,
-                details={"num_null_rows": 3, "pct_null_rows": 75},
-            ).to_dict(),
-            DataCheckError(
-                message="Binary class targets require exactly two unique values.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
-                details={"target_values": [0]},
-            ).to_dict(),
-        ],
-        "actions": [
-            DataCheckAction(
-                DataCheckActionCode.IMPUTE_COL,
-                data_check_name=invalid_targets_data_check_name,
-                metadata={
-                    "is_target": True,
-                    "impute_strategy": "most_frequent",
-                },
-            ).to_dict()
-        ],
-    }
+    expected = [
+        DataCheckError(
+            message="3 row(s) (75.0%) of target values are null",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_HAS_NULL,
+            details={"num_null_rows": 3, "pct_null_rows": 75},
+            action_options=[
+                DataCheckActionOption(
+                    DataCheckActionCode.IMPUTE_COL,
+                    data_check_name=invalid_targets_data_check_name,
+                    parameters={
+                        "impute_strategy": {
+                            "parameter_type": DCAOParameterType.GLOBAL,
+                            "type": "category",
+                            "categories": ["most_frequent"],
+                            "default_value": "most_frequent",
+                        }
+                    },
+                    metadata={"is_target": True},
+                )
+            ],
+        ).to_dict(),
+        DataCheckError(
+            message="Binary class targets require exactly two unique values.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
+            details={"target_values": [0]},
+        ).to_dict(),
+    ]
     #  test Woodwork
     y = pd.Series([None, None, None, 0])
     X = pd.DataFrame({"col": range(len(y))})
@@ -263,36 +230,28 @@ def test_invalid_target_data_check_n_unique(problem_type):
         problem_type, get_default_primary_search_objective(problem_type)
     )
     # Test default value of n_unique
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Binary class targets require exactly two unique values.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
-                details={"target_values": unique_values},
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == [
+        DataCheckError(
+            message="Binary class targets require exactly two unique values.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
+            details={"target_values": unique_values},
+        ).to_dict()
+    ]
 
     # Test number of unique values < n_unique
     y = pd.Series(range(20))
     X = pd.DataFrame({"col": range(len(y))})
 
     unique_values = y.value_counts().index.tolist()
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Binary class targets require exactly two unique values.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
-                details={"target_values": unique_values},
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == [
+        DataCheckError(
+            message="Binary class targets require exactly two unique values.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
+            details={"target_values": unique_values},
+        ).to_dict()
+    ]
 
     # Test n_unique is None
     invalid_targets_check = InvalidTargetDataCheck(
@@ -302,18 +261,14 @@ def test_invalid_target_data_check_n_unique(problem_type):
     X = pd.DataFrame({"col": range(len(y))})
 
     unique_values = y.value_counts().index.tolist()
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Binary class targets require exactly two unique values.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
-                details={"target_values": unique_values},
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == [
+        DataCheckError(
+            message="Binary class targets require exactly two unique values.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_BINARY_NOT_TWO_UNIQUE_VALUES,
+            details={"target_values": unique_values},
+        ).to_dict()
+    ]
 
 
 @pytest.mark.parametrize(
@@ -339,22 +294,16 @@ def test_invalid_target_data_check_invalid_labels_for_nonnegative_objective_name
             }
         },
     )
-    assert data_checks.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message=f"Target has non-positive values which is not supported for {objective}",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_INCOMPATIBLE_OBJECTIVE,
-                details={
-                    "Count of offending values": sum(
-                        val <= 0 for val in y.values.flatten()
-                    )
-                },
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert data_checks.validate(X, y) == [
+        DataCheckError(
+            message=f"Target has non-positive values which is not supported for {objective}",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_INCOMPATIBLE_OBJECTIVE,
+            details={
+                "Count of offending values": sum(val <= 0 for val in y.values.flatten())
+            },
+        ).to_dict()
+    ]
 
     X = pd.DataFrame({"column_one": [100, 200, 100, 200, 100]})
     y = pd.Series([2, 3, 0, 1, 1])
@@ -363,22 +312,16 @@ def test_invalid_target_data_check_invalid_labels_for_nonnegative_objective_name
         problem_type="regression", objective=objective
     )
 
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message=f"Target has non-positive values which is not supported for {objective}",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_INCOMPATIBLE_OBJECTIVE,
-                details={
-                    "Count of offending values": sum(
-                        val <= 0 for val in y.values.flatten()
-                    )
-                },
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == [
+        DataCheckError(
+            message=f"Target has non-positive values which is not supported for {objective}",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_INCOMPATIBLE_OBJECTIVE,
+            details={
+                "Count of offending values": sum(val <= 0 for val in y.values.flatten())
+            },
+        ).to_dict()
+    ]
 
 
 @pytest.mark.parametrize(
@@ -400,22 +343,16 @@ def test_invalid_target_data_check_invalid_labels_for_nonnegative_objective_inst
         },
     )
 
-    assert data_checks.validate(X, y) == {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message=f"Target has non-positive values which is not supported for {objective.name}",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_INCOMPATIBLE_OBJECTIVE,
-                details={
-                    "Count of offending values": sum(
-                        val <= 0 for val in y.values.flatten()
-                    )
-                },
-            ).to_dict()
-        ],
-        "actions": [],
-    }
+    assert data_checks.validate(X, y) == [
+        DataCheckError(
+            message=f"Target has non-positive values which is not supported for {objective.name}",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_INCOMPATIBLE_OBJECTIVE,
+            details={
+                "Count of offending values": sum(val <= 0 for val in y.values.flatten())
+            },
+        ).to_dict()
+    ]
 
 
 def test_invalid_target_data_check_invalid_labels_for_objectives(
@@ -435,11 +372,7 @@ def test_invalid_target_data_check_invalid_labels_for_objectives(
                     }
                 },
             )
-            assert data_checks.validate(X, y) == {
-                "warnings": [],
-                "errors": [],
-                "actions": [],
-            }
+            assert data_checks.validate(X, y) == []
 
     X = pd.DataFrame({"column_one": [100, 200, 100, 200, 100]})
     y = pd.Series([2, 3, 0, 1, 1])
@@ -449,11 +382,7 @@ def test_invalid_target_data_check_invalid_labels_for_objectives(
             invalid_targets_check = InvalidTargetDataCheck(
                 problem_type="regression", objective=objective
             )
-            assert invalid_targets_check.validate(X, y) == {
-                "warnings": [],
-                "errors": [],
-                "actions": [],
-            }
+            assert invalid_targets_check.validate(X, y) == []
 
 
 @pytest.mark.parametrize(
@@ -477,7 +406,7 @@ def test_invalid_target_data_check_valid_labels_for_nonnegative_objectives(objec
             }
         },
     )
-    assert data_checks.validate(X, y) == {"warnings": [], "errors": [], "actions": []}
+    assert data_checks.validate(X, y) == []
 
 
 def test_invalid_target_data_check_initialize_with_none_objective():
@@ -515,19 +444,28 @@ def test_invalid_target_data_check_regression_problem_nonnumeric_data(problem_ty
     )
     assert invalid_targets_check.validate(
         X=pd.DataFrame({"col": range(len(y_categorical))}), y=y_categorical
-    ) == {"warnings": [], "errors": [data_check_error], "actions": []}
+    ) == [data_check_error]
     assert invalid_targets_check.validate(
         X=pd.DataFrame({"col": range(len(y_mixed_cat_numeric))}), y=y_mixed_cat_numeric
-    ) == {"warnings": [], "errors": [data_check_error], "actions": []}
-    assert invalid_targets_check.validate(
-        X=pd.DataFrame({"col": range(len(y_integer))}), y=y_integer
-    ) == {"warnings": [], "errors": [], "actions": []}
-    assert invalid_targets_check.validate(
-        X=pd.DataFrame({"col": range(len(y_float))}), y=y_float
-    ) == {"warnings": [], "errors": [], "actions": []}
-    assert invalid_targets_check.validate(
-        X=pd.DataFrame({"col": range(len(y_numeric))}), y=y_numeric
-    ) == {"warnings": [], "errors": [], "actions": []}
+    ) == [data_check_error]
+    assert (
+        invalid_targets_check.validate(
+            X=pd.DataFrame({"col": range(len(y_integer))}), y=y_integer
+        )
+        == []
+    )
+    assert (
+        invalid_targets_check.validate(
+            X=pd.DataFrame({"col": range(len(y_float))}), y=y_float
+        )
+        == []
+    )
+    assert (
+        invalid_targets_check.validate(
+            X=pd.DataFrame({"col": range(len(y_numeric))}), y=y_numeric
+        )
+        == []
+    )
 
 
 @pytest.mark.parametrize(
@@ -547,12 +485,15 @@ def test_invalid_target_data_check_multiclass_problem_binary_data(problem_type):
     invalid_targets_check = InvalidTargetDataCheck(
         "multiclass", get_default_primary_search_objective("multiclass")
     )
-    assert invalid_targets_check.validate(
-        X=pd.DataFrame({"col": range(len(y_multiclass))}), y=y_multiclass
-    ) == {"warnings": [], "errors": [], "actions": []}
+    assert (
+        invalid_targets_check.validate(
+            X=pd.DataFrame({"col": range(len(y_multiclass))}), y=y_multiclass
+        )
+        == []
+    )
     assert invalid_targets_check.validate(
         X=pd.DataFrame({"col": range(len(y_binary))}), y=y_binary
-    ) == {"warnings": [], "errors": [data_check_error], "actions": []}
+    ) == [data_check_error]
 
 
 @pytest.mark.parametrize(
@@ -574,11 +515,9 @@ def test_invalid_target_data_check_multiclass_problem_almost_continuous_data(
         message_code=DataCheckMessageCode.TARGET_MULTICLASS_HIGH_UNIQUE_CLASS,
         details={"class_to_value_ratio": 1 / 3},
     ).to_dict()
-    assert invalid_targets_check.validate(X, y=y_multiclass_high_classes) == {
-        "warnings": [data_check_warning],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y=y_multiclass_high_classes) == [
+        data_check_warning
+    ]
 
     y_multiclass_med_classes = pd.Series(
         list(range(0, 5)) * 20
@@ -590,21 +529,15 @@ def test_invalid_target_data_check_multiclass_problem_almost_continuous_data(
         message_code=DataCheckMessageCode.TARGET_MULTICLASS_HIGH_UNIQUE_CLASS,
         details={"class_to_value_ratio": 0.05},
     ).to_dict()
-    assert invalid_targets_check.validate(X, y=y_multiclass_med_classes) == {
-        "warnings": [data_check_warning],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y=y_multiclass_med_classes) == [
+        data_check_warning
+    ]
 
     y_multiclass_low_classes = pd.Series(
         list(range(0, 3)) * 100
     )  # 2 classes, 300 samples, .01 class/sample ratio
     X = pd.DataFrame({"col": range(len(y_multiclass_low_classes))})
-    assert invalid_targets_check.validate(X, y=y_multiclass_low_classes) == {
-        "warnings": [],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y=y_multiclass_low_classes) == []
 
 
 def test_invalid_target_data_check_mismatched_indices():
@@ -616,67 +549,47 @@ def test_invalid_target_data_check_mismatched_indices():
     invalid_targets_check = InvalidTargetDataCheck(
         "binary", get_default_primary_search_objective("binary")
     )
-    assert invalid_targets_check.validate(X=None, y=y_same_index) == {
-        "warnings": [],
-        "errors": [],
-        "actions": [],
-    }
-    assert invalid_targets_check.validate(X, y_same_index) == {
-        "warnings": [],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X=None, y=y_same_index) == []
+    assert invalid_targets_check.validate(X, y_same_index) == []
 
     X_index_missing = list(set(y_diff_index.index) - set(X.index))
     y_index_missing = list(set(X.index) - set(y_diff_index.index))
-    assert invalid_targets_check.validate(X, y_diff_index) == {
-        "warnings": [
-            DataCheckWarning(
-                message="Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.MISMATCHED_INDICES,
-                details={
-                    "indices_not_in_features": X_index_missing,
-                    "indices_not_in_target": y_index_missing,
-                },
-            ).to_dict()
-        ],
-        "errors": [],
-        "actions": [],
-    }
-    assert invalid_targets_check.validate(X, y_diff_index_order) == {
-        "warnings": [
-            DataCheckWarning(
-                message="Input target and features have mismatched indices order.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.MISMATCHED_INDICES_ORDER,
-                details={},
-            ).to_dict()
-        ],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y_diff_index) == [
+        DataCheckWarning(
+            message="Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.MISMATCHED_INDICES,
+            details={
+                "indices_not_in_features": X_index_missing,
+                "indices_not_in_target": y_index_missing,
+            },
+        ).to_dict()
+    ]
+    assert invalid_targets_check.validate(X, y_diff_index_order) == [
+        DataCheckWarning(
+            message="Input target and features have mismatched indices order.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.MISMATCHED_INDICES_ORDER,
+            details={},
+        ).to_dict()
+    ]
 
     # Test that we only store ten mismatches when there are more than 10 differences in indices found
     X_large = pd.DataFrame({"col": range(20)})
     y_more_than_ten_diff_indices = pd.Series([0, 1] * 10, index=range(20, 40))
     X_index_missing = list(set(y_more_than_ten_diff_indices.index) - set(X.index))
     y_index_missing = list(set(X_large.index) - set(y_more_than_ten_diff_indices.index))
-    assert invalid_targets_check.validate(X_large, y_more_than_ten_diff_indices) == {
-        "warnings": [
-            DataCheckWarning(
-                message="Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.MISMATCHED_INDICES,
-                details={
-                    "indices_not_in_features": X_index_missing[:10],
-                    "indices_not_in_target": y_index_missing[:10],
-                },
-            ).to_dict()
-        ],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X_large, y_more_than_ten_diff_indices) == [
+        DataCheckWarning(
+            message="Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.MISMATCHED_INDICES,
+            details={
+                "indices_not_in_features": X_index_missing[:10],
+                "indices_not_in_target": y_index_missing[:10],
+            },
+        ).to_dict()
+    ]
 
 
 def test_invalid_target_data_check_different_lengths():
@@ -685,27 +598,23 @@ def test_invalid_target_data_check_different_lengths():
     invalid_targets_check = InvalidTargetDataCheck(
         "binary", get_default_primary_search_objective("binary")
     )
-    assert invalid_targets_check.validate(X, y_diff_len) == {
-        "warnings": [
-            DataCheckWarning(
-                message="Input target and features have different lengths",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.MISMATCHED_LENGTHS,
-                details={
-                    "features_length": len(X.index),
-                    "target_length": len(y_diff_len.index),
-                },
-            ).to_dict(),
-            DataCheckWarning(
-                message="Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.MISMATCHED_INDICES,
-                details={"indices_not_in_features": [], "indices_not_in_target": [2]},
-            ).to_dict(),
-        ],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y_diff_len) == [
+        DataCheckWarning(
+            message="Input target and features have different lengths",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.MISMATCHED_LENGTHS,
+            details={
+                "features_length": len(X.index),
+                "target_length": len(y_diff_len.index),
+            },
+        ).to_dict(),
+        DataCheckWarning(
+            message="Input target and features have mismatched indices. Details will include the first 10 mismatched indices.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.MISMATCHED_INDICES,
+            details={"indices_not_in_features": [], "indices_not_in_target": [2]},
+        ).to_dict(),
+    ]
 
 
 @pytest.mark.parametrize(
@@ -719,16 +628,12 @@ def test_invalid_target_data_check_numeric_binary_does_not_return_warnings(
     invalid_targets_check = InvalidTargetDataCheck(
         problem_type, get_default_primary_search_objective(problem_type)
     )
-    assert invalid_targets_check.validate(X, y) == {
-        "warnings": [],
-        "errors": [],
-        "actions": [],
-    }
+    assert invalid_targets_check.validate(X, y) == []
 
 
 @pytest.mark.parametrize("use_nullable_types", [True, False])
 @pytest.mark.parametrize("problem_type", ProblemTypes.all_problem_types)
-def test_invalid_target_data_action_for_data_with_null(
+def test_invalid_target_data_check_action_for_data_with_null(
     use_nullable_types, problem_type
 ):
     y = pd.Series([None, None, None, 0, 0, 0, 0, 0, 0, 0])
@@ -739,31 +644,35 @@ def test_invalid_target_data_action_for_data_with_null(
     invalid_targets_check = InvalidTargetDataCheck(
         problem_type, get_default_primary_search_objective(problem_type)
     )
-    impute_strategy = "mean" if is_regression(problem_type) else "most_frequent"
-
-    expected = {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="3 row(s) (30.0%) of target values are null",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_HAS_NULL,
-                details={"num_null_rows": 3, "pct_null_rows": 30.0},
-            ).to_dict()
-        ],
-        "actions": [
-            DataCheckAction(
-                DataCheckActionCode.IMPUTE_COL,
-                data_check_name=invalid_targets_data_check_name,
-                metadata={
-                    "is_target": True,
-                    "impute_strategy": impute_strategy,
-                },
-            ).to_dict()
-        ],
-    }
+    expected = [
+        DataCheckError(
+            message="3 row(s) (30.0%) of target values are null",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_HAS_NULL,
+            details={"num_null_rows": 3, "pct_null_rows": 30.0},
+            action_options=[
+                DataCheckActionOption(
+                    DataCheckActionCode.IMPUTE_COL,
+                    data_check_name=invalid_targets_data_check_name,
+                    parameters={
+                        "impute_strategy": {
+                            "parameter_type": DCAOParameterType.GLOBAL,
+                            "type": "category",
+                            "categories": ["mean", "most_frequent"]
+                            if is_regression(problem_type)
+                            else ["most_frequent"],
+                            "default_value": "mean"
+                            if is_regression(problem_type)
+                            else "most_frequent",
+                        }
+                    },
+                    metadata={"is_target": True},
+                )
+            ],
+        ).to_dict()
+    ]
     if is_binary(problem_type):
-        expected["errors"].append(
+        expected.append(
             DataCheckError(
                 message="Binary class targets require exactly two unique values.",
                 data_check_name=invalid_targets_data_check_name,
@@ -772,7 +681,7 @@ def test_invalid_target_data_action_for_data_with_null(
             ).to_dict()
         )
     elif is_multiclass(problem_type):
-        expected["errors"].append(
+        expected.append(
             DataCheckError(
                 message=f"Target has two or less classes, which is too few for multiclass problems.  Consider changing to binary.",
                 data_check_name=invalid_targets_data_check_name,
@@ -780,7 +689,7 @@ def test_invalid_target_data_action_for_data_with_null(
                 details={"num_classes": 1},
             ).to_dict()
         )
-        expected["warnings"].append(
+        expected.append(
             DataCheckWarning(
                 message=f"Target has a large number of unique values, could be regression type problem.",
                 data_check_name=invalid_targets_data_check_name,
@@ -794,7 +703,7 @@ def test_invalid_target_data_action_for_data_with_null(
 
 
 @pytest.mark.parametrize("problem_type", ProblemTypes.all_problem_types)
-def test_invalid_target_data_action_for_all_null(problem_type):
+def test_invalid_target_data_check_action_for_all_null(problem_type):
     invalid_targets_check = InvalidTargetDataCheck(
         problem_type, get_default_primary_search_objective(problem_type)
     )
@@ -802,17 +711,13 @@ def test_invalid_target_data_action_for_all_null(problem_type):
     y_all_null = pd.Series([None, None, None])
     X = pd.DataFrame({"col": range(len(y_all_null))})
 
-    expected = {
-        "warnings": [],
-        "errors": [
-            DataCheckError(
-                message="Target is either empty or fully null.",
-                data_check_name=invalid_targets_data_check_name,
-                message_code=DataCheckMessageCode.TARGET_IS_EMPTY_OR_FULLY_NULL,
-                details={},
-            ).to_dict(),
-        ],
-        "actions": [],
-    }
+    expected = [
+        DataCheckError(
+            message="Target is either empty or fully null.",
+            data_check_name=invalid_targets_data_check_name,
+            message_code=DataCheckMessageCode.TARGET_IS_EMPTY_OR_FULLY_NULL,
+            details={},
+        ).to_dict(),
+    ]
     messages = invalid_targets_check.validate(X, y_all_null)
     assert messages == expected
